@@ -1,18 +1,15 @@
 import { readInput, writeOutput } from './common';
 import katex from 'katex';
+import 'katex/contrib/mhchem/mhchem.js';
 
 const render = function (input) {
 	const data = input.data;
 	const expression = data.expression;
 	const options = data.options;
 	const header = input.header;
-	try {
-		const output = katex.renderToString(expression, options);
-		writeOutput({ header: header, data: { output: output } });
-	} catch (e) {
-		header.err = e.message;
-		writeOutput({ header: header });
-	}
+	// Any error thrown here will be caught by the common.js readInput function.
+	const output = katex.renderToString(expression, options);
+	writeOutput({ header: header, data: { output: output } });
 };
 
 readInput(render);
