@@ -15,9 +15,9 @@
 package goldmark_config
 
 const (
-	AutoHeadingIDTypeGitHub      = "github"
-	AutoHeadingIDTypeGitHubAscii = "github-ascii"
-	AutoHeadingIDTypeBlackfriday = "blackfriday"
+	AutoIDTypeGitHub      = "github"
+	AutoIDTypeGitHubAscii = "github-ascii"
+	AutoIDTypeBlackfriday = "blackfriday"
 )
 
 // Default holds the default Goldmark configuration.
@@ -49,6 +49,23 @@ var Default = Config{
 			EastAsianLineBreaksStyle: "simple",
 			EscapedSpace:             false,
 		},
+		Extras: Extras{
+			Delete: Delete{
+				Enable: false,
+			},
+			Insert: Insert{
+				Enable: false,
+			},
+			Mark: Mark{
+				Enable: false,
+			},
+			Subscript: Subscript{
+				Enable: false,
+			},
+			Superscript: Superscript{
+				Enable: false,
+			},
+		},
 		Passthrough: Passthrough{
 			Enable: false,
 			Delimiters: DelimitersConfig{
@@ -62,7 +79,8 @@ var Default = Config{
 	},
 	Parser: Parser{
 		AutoHeadingID:                      true,
-		AutoHeadingIDType:                  AutoHeadingIDTypeGitHub,
+		AutoDefinitionTermID:               false,
+		AutoIDType:                         AutoIDTypeGitHub,
 		WrapStandAloneImageWithinParagraph: true,
 		Attribute: ParserAttribute{
 			Title: true,
@@ -80,6 +98,16 @@ type Config struct {
 	RenderHooks            RenderHooks
 }
 
+func (c *Config) Init() error {
+	if err := c.Parser.Init(); err != nil {
+		return err
+	}
+	if c.Parser.AutoDefinitionTermID && !c.Extensions.DefinitionList {
+		c.Parser.AutoDefinitionTermID = false
+	}
+	return nil
+}
+
 // RenderHooks contains configuration for Goldmark render hooks.
 type RenderHooks struct {
 	Image ImageRenderHook
@@ -112,6 +140,7 @@ type Extensions struct {
 	Typographer    Typographer
 	Footnote       bool
 	DefinitionList bool
+	Extras         Extras
 	Passthrough    Passthrough
 
 	// GitHub flavored markdown
@@ -150,7 +179,37 @@ type Typographer struct {
 	Apostrophe string
 }
 
-// Passthrough hold passthrough configuration.
+// Extras holds extras configuration.
+// github.com/hugoio/hugo-goldmark-extensions/extras
+type Extras struct {
+	Delete      Delete
+	Insert      Insert
+	Mark        Mark
+	Subscript   Subscript
+	Superscript Superscript
+}
+
+type Delete struct {
+	Enable bool
+}
+
+type Insert struct {
+	Enable bool
+}
+
+type Mark struct {
+	Enable bool
+}
+
+type Subscript struct {
+	Enable bool
+}
+
+type Superscript struct {
+	Enable bool
+}
+
+// Passthrough holds passthrough configuration.
 // github.com/hugoio/hugo-goldmark-extensions/passthrough
 type Passthrough struct {
 	// Whether to enable the extension
@@ -202,16 +261,30 @@ type Parser struct {
 	// auto generated heading ids.
 	AutoHeadingID bool
 
-	// The strategy to use when generating heading IDs.
-	// Available options are "github", "github-ascii".
+	// Enables auto definition term ids.
+	AutoDefinitionTermID bool
+
+	// The strategy to use when generating IDs.
+	// Available options are "github", "github-ascii", and "blackfriday".
 	// Default is "github", which will create GitHub-compatible anchor names.
-	AutoHeadingIDType string
+	AutoIDType string
 
 	// Enables custom attributes.
 	Attribute ParserAttribute
 
 	// Whether to wrap stand-alone images within a paragraph or not.
 	WrapStandAloneImageWithinParagraph bool
+
+	// Renamed to AutoIDType in 0.144.0.
+	AutoHeadingIDType string `json:"-"`
+}
+
+func (p *Parser) Init() error {
+	// Renamed from AutoHeadingIDType to AutoIDType in 0.144.0.
+	if p.AutoHeadingIDType != "" {
+		p.AutoIDType = p.AutoHeadingIDType
+	}
+	return nil
 }
 
 type ParserAttribute struct {
